pub fn read_fill_choice(
reader: &mut Reader<'_>,
start: &BytesStart<'_>,
is_start: bool,
) -> Result<Fill, Error>Expand description
See is_fill_choice_element’s own doc comment for when to reach for this instead of
read_fill.
pub fn read_fill_choice(
reader: &mut Reader<'_>,
start: &BytesStart<'_>,
is_start: bool,
) -> Result<Fill, Error>See is_fill_choice_element’s own doc comment for when to reach for this instead of
read_fill.