pub struct DrawingAnchor {
pub from: CellAnchorPoint,
pub to: CellAnchorPoint,
pub object: DrawingObject,
}Expand description
One cell-anchored drawing object (<xdr:twoCellAnchor>, CT_TwoCellAnchor).
Only the two-cell anchor is modeled (from/to cell markers, editAs always the schema
default "twoCell") — by far the common case real spreadsheet tools generate
(CT_OneCellAnchor/ CT_AbsoluteAnchor exist in the schema but are rarely if ever generated,
only tolerated on read). A wholly absent anchor kind on read is simply skipped by this crate’s
forgiving reader, consistent with the rest of this workspace’s posture.
Fields
from: CellAnchorPointto: CellAnchorPointobject: DrawingObjectImplementations
Sourceimpl DrawingAnchor
impl DrawingAnchor
Sourcepub fn new(
from: CellAnchorPoint,
to: CellAnchorPoint,
object: DrawingObject,
) -> DrawingAnchor
pub fn new( from: CellAnchorPoint, to: CellAnchorPoint, object: DrawingObject, ) -> DrawingAnchor
Examples found in repository?
examples/xlsx_images_and_charts.rs (lines 28-32)
21fn main() -> office_toolkit::Result<()> {
22 let path = output_path("xlsx_images_and_charts.xlsx");
23 let image_bytes = std::fs::read(image_fixture_path())?;
24
25 let picture = SheetPicture::new(image_bytes, PictureFormat::Png).with_name("Test image");
26 let picture_sheet = Sheet::new("Picture")
27 .with_row(Row::new().with_text("The picture is anchored to cell A1:"))
28 .with_drawing(SheetDrawing::new().with_anchor(DrawingAnchor::new(
29 CellAnchorPoint::new(0, 1),
30 CellAnchorPoint::new(2, 6),
31 DrawingObject::Picture(Box::new(picture)),
32 )));
33
34 let chart = SheetChart::new(sample_chart_space()).with_name("Quarterly revenue");
35 let chart_sheet = Sheet::new("Chart")
36 .with_row(Row::new().with_text("A bar chart is anchored below:"))
37 .with_drawing(SheetDrawing::new().with_anchor(DrawingAnchor::new(
38 CellAnchorPoint::new(0, 1),
39 CellAnchorPoint::new(6, 16),
40 DrawingObject::Chart(Box::new(chart)),
41 )));
42
43 let workbook = Workbook::new()
44 .with_sheet(picture_sheet)
45 .with_sheet(chart_sheet);
46 workbook.save_to_file(&path)?;
47 println!("Wrote {}", path.display());
48 Ok(())
49}Trait Implementations
Sourceimpl Clone for DrawingAnchor
impl Clone for DrawingAnchor
Sourcefn clone(&self) -> DrawingAnchor
fn clone(&self) -> DrawingAnchor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DrawingAnchor
impl Debug for DrawingAnchor
Sourceimpl PartialEq for DrawingAnchor
impl PartialEq for DrawingAnchor
impl StructuralPartialEq for DrawingAnchor