pub enum BreakKind {
Page,
Column,
TextWrapping,
}Expand description
The kind of an explicit break (<w:br w:type="..">, CT_Br, ST_BrType), see
RunContent::Break.
Variants
Page
Forces a page break at this point in the text.
Column
Forces a column break (only meaningful in a multi-column section, see
PageSetup::columns).
TextWrapping
A line break within the same paragraph (the text continues on the next line without starting
a new paragraph) — ST_BrType’s default value when w:br’s type attribute is omitted
entirely.
Implementations