pub enum NoteKind {
Footnote,
Endnote,
}Expand description
Which kind of note a RunContent::NoteMarker renders the number of
(<w:footnoteRef/>/<w:endnoteRef/>, both CT_Empty).
Used as the first run of a footnote/endnote’s own first paragraph, to render its own number
inline with its text — e.g. the superscript “1” at the very start of a footnote’s text. Distinct
from NoteReference, which is what goes in the document body to point at a note; this is
what goes inside the note itself, rendering its own number.
Variants