pub fn write_text_paragraph_properties<W>(
writer: &mut Writer<W>,
properties: &TextParagraphProperties,
) -> Result<(), Error>where
W: Write,Expand description
Writes <a:pPr> — self-closing when nothing beyond its own attributes is set, otherwise wraps
<a:lnSpc>/<a:spcBef>/<a:spcAft>/bullet elements/<a:tabLst>/<a:defRPr> children, in
that order — the same child sequence confirmed on a real fixture
(<a:lnSpc>..<a:spcBef>..<a:spcAft>..<a:buClrTx/><a:buSzTx/> <a:buFontTx/><a:buNone/><a:tabLst/><a:defRPr/>).